@@ -12,7 +12,7 @@ def new(column: str):
 
 
 def main():
-    app()
+    return app()
 
 
 if __name__ == "__main__":
